ewa.ply.yacc.LRGeneratedTable

Package ewa :: Package ply :: Module yacc :: Class LRGeneratedTable |
[hide private]
[frames] | no frames]

# Class LRGeneratedTable

source code

    object --+
             |
       LRTable --+
                 |
                LRGeneratedTable

Instance Methods | [hide private]
__init__(self, grammar, method=`'``LALR``'`, log=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
lr0_closure(self, I) | source code
lr0_goto(self, I, x) | source code
lr0_items(self) | source code
compute_nullable_nonterminals(self) | source code
find_nonterminal_transitions(self, C) | source code
dr_relation(self, C, trans, nullable) | source code
reads_relation(self, C, trans, empty) | source code
compute_lookback_includes(self, C, trans, nullable) | source code
compute_read_sets(self, C, ntrans, nullable) | source code
compute_follow_sets(self, ntrans, readsets, inclsets) | source code
add_lookaheads(self, lookbacks, followset) | source code
add_lalr_lookaheads(self, C) | source code
lr_parse_table(self) | source code
write_table(self, modulename, outputdir=`'````'`, signature=`'````'`) | source code
pickle_table(self, filename, signature=`'````'`) | source code
Inherited from `LRTable`: `bind_callables`, `read_pickle`, `read_table` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, grammar, method=`'``LALR``'`, log=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)